==> dolfin-0.9.4.tar.gz: dolfin-0.9.4/site-packages/dolfin/specialfunctions.py <==
# -*- coding: utf-8 -*-
"""This module defines some special functions
(originally defined in SpecialFunctions.h)."""

__author__ = "Anders Logg (logg@simula.no)"
__date__ = "2008-12-08 -- 2009-10-06"
__copyright__ = "Copyright (C) 2008-2009 Anders Logg"
__license__  = "GNU LGPL Version 2.1"

# Modified by Johan Hake, 2008-2009 

__all__ = ["MeshCoordinates", "CellSize", "FacetArea"]#, "SUPGStabilizer"]

# Import UFL and SWIG-generated extension module (DOLFIN C++)
import ufl
import cpp

# Local imports
from functionspace import dim2domain
from expression import Expression

class MeshCoordinates(Expression, ufl.Function, cpp.MeshCoordinates):
    def __init__(self, mesh):
        "Create function that evaluates to the mesh coordinates at each vertex."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.VectorElement("Lagrange", domain, 1)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.MeshCoordinates.__init__(self, mesh)

MeshCoordinates.__doc__ = cpp.MeshCoordinates.__doc__

class CellSize(Expression, ufl.Function, cpp.CellSize):
    def __init__(self, mesh):
        "Create function that evaluates to the local cell size."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.FiniteElement("Discontinuous Lagrange", domain, 0)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.CellSize.__init__(self, mesh)

CellSize.__doc__ = cpp.CellSize.__doc__

class FacetArea(Expression, ufl.Function, cpp.FacetArea):

    def __init__(self, mesh):
        "Create function that evaluates to the facet area/length on each facet."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.FiniteElement("Discontinuous Lagrange", domain, 0)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.FacetArea.__init__(self, mesh)

FacetArea.__doc__ = cpp.FacetArea.__doc__

==> dolfin-0.9.5.tar.gz: dolfin-0.9.5/site-packages/dolfin/specialfunctions.py <==
# -*- coding: utf-8 -*-
"""This module defines some special functions
(originally defined in SpecialFunctions.h)."""

__author__ = "Anders Logg (logg@simula.no)"
__date__ = "2008-12-08 -- 2009-10-06"
__copyright__ = "Copyright (C) 2008-2009 Anders Logg"
__license__  = "GNU LGPL Version 2.1"

# Modified by Johan Hake, 2008-2009

__all__ = ["MeshCoordinates", "CellSize", "FacetArea", "FacetNormal"]

# "SUPGStabilizer"

# Import UFL and SWIG-generated extension module (DOLFIN C++)
import ufl
import cpp

# Local imports
from functionspace import dim2domain
from expression import Expression

class MeshCoordinates(Expression, ufl.Function, cpp.MeshCoordinates):
    def __init__(self, mesh):
        "Create function that evaluates to the mesh coordinates at each vertex."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.VectorElement("Lagrange", domain, 1)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.MeshCoordinates.__init__(self, mesh)

MeshCoordinates.__doc__ = cpp.MeshCoordinates.__doc__

class CellSize(Expression, ufl.Function, cpp.CellSize):
    def __init__(self, mesh):
        "Create function that evaluates to the local cell size."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.FiniteElement("Discontinuous Lagrange", domain, 0)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.CellSize.__init__(self, mesh)

CellSize.__doc__ = cpp.CellSize.__doc__

class FacetArea(Expression, ufl.Function, cpp.FacetArea):

    def __init__(self, mesh):
        "Create function that evaluates to the facet area/length on each facet."

        domain = dim2domain[mesh.topology().dim()]
        self._ufl_element = ufl.FiniteElement("Discontinuous Lagrange", domain, 0)

        ufl.Function.__init__(self, self._ufl_element)
        cpp.FacetArea.__init__(self, mesh)

FacetArea.__doc__ = cpp.FacetArea.__doc__

# Simple definition of FacetNormal without needing to refer to UFL cells
def FacetNormal(mesh):
    "Return facet normal function for given mesh."
    if mesh.topology().dim() == 1:
        return ufl.interval.n
    elif mesh.topology().dim() == 2:
        return ufl.triangle.n
    elif mesh.topology().dim() == 3:
        return ufl.tetrahedron.n
    else:
        cpp.error("Unable to create facet normal, unhandled topological dimension %s." % str(mesh.topology().dim()))
